==> openjdk-21_21.0.10~6ea.orig.tar.xz: openjdk-21-21.0.10~6ea/test/hotspot/jtreg/vmTestbase/vm/mlvm/cp/share/HandleType.java <==
/*
 * Copyright (c) 2016, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package vm.mlvm.cp.share;

import jdk.internal.org.objectweb.asm.Opcodes;

public enum HandleType {
    GETFIELD(Opcodes.H_GETFIELD),
    PUTFIELD(Opcodes.H_PUTFIELD),
    GETSTATIC(Opcodes.H_GETSTATIC),
    PUTSTATIC(Opcodes.H_PUTSTATIC),
    NEWINVOKESPECIAL(Opcodes.H_NEWINVOKESPECIAL),
    INVOKESTATIC(Opcodes.H_INVOKESTATIC),
    INVOKEINTERFACE(Opcodes.H_INVOKEINTERFACE),
    INVOKESPECIAL(Opcodes.H_INVOKESPECIAL),
    INVOKEVIRTUAL(Opcodes.H_INVOKEVIRTUAL);

    public final int asmTag;
    private HandleType(int asmTag) {
        this.asmTag = asmTag;
    }
}

==> openjdk-26_26~26ea.orig.tar.xz: openjdk-26-26~26ea/test/hotspot/jtreg/vmTestbase/vm/mlvm/cp/share/HandleType.java <==
/*
 * Copyright (c) 2016, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package vm.mlvm.cp.share;

import org.objectweb.asm.Opcodes;

public enum HandleType {
    GETFIELD(Opcodes.H_GETFIELD),
    PUTFIELD(Opcodes.H_PUTFIELD),
    GETSTATIC(Opcodes.H_GETSTATIC),
    PUTSTATIC(Opcodes.H_PUTSTATIC),
    NEWINVOKESPECIAL(Opcodes.H_NEWINVOKESPECIAL),
    INVOKESTATIC(Opcodes.H_INVOKESTATIC),
    INVOKEINTERFACE(Opcodes.H_INVOKEINTERFACE),
    INVOKESPECIAL(Opcodes.H_INVOKESPECIAL),
    INVOKEVIRTUAL(Opcodes.H_INVOKEVIRTUAL);

    public final int asmTag;
    private HandleType(int asmTag) {
        this.asmTag = asmTag;
    }
}
